use std::path::Path;

use axum::http::{StatusCode, Uri};
use axum_htmx::AutoVaryLayer;
use tower_http::services::ServeDir;

mod menu;
mod pages;

async fn fallback(uri: Uri) -> (StatusCode, String) {
    (StatusCode::NOT_FOUND, format!("No route for {uri}"))
}

pub fn get_router(assets_path: &Path) -> axum::Router {
    axum::Router::new()
        .nest_service("/assets", ServeDir::new(assets_path))
        .merge(pages::get_routes())
        .fallback(fallback)
        .layer(AutoVaryLayer)
}
